#ifndef _MONETARY_H_
#define _MONETARY_H_

#include <sys/types.h>
#include <stddef.h>

#ifdef __cplusplus
extern "C" {
#endif





    extern ssize_t strfmon(char *, size_t, const char *, ...);
#ifdef __cplusplus
}
#endif
#endif
